@@ -4,8 +4,7 @@ use warnings;
 
 package Log::Any::Adapter::Test;
 
-# ABSTRACT: Backend adapter for Log::Any::Test
-our $VERSION = '0.90'; # TRIAL
+our $VERSION = '0.91'; # TRIAL
 
 use Data::Dumper;
 use Log::Any;
@@ -166,44 +165,3 @@ sub _first_index {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Log::Any::Adapter::Test - Backend adapter for Log::Any::Test
-
-=head1 VERSION
-
-version 0.90
-
-=head1 SEE ALSO
-
-L<Log::Any|Log::Any>, L<Log::Any::Adapter|Log::Any::Adapter>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-David Golden <dagolden@cpan.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
